@@ -1,6 +1,4 @@
-# -*- coding: utf-8 -*-
-#
-# Copyright 2010-2014 The pygit2 contributors
+# Copyright 2010-2025 The pygit2 contributors
 #
 # This file is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License, version 2,
@@ -25,78 +23,75 @@
 # the Free Software Foundation, 51 Franklin Street, Fifth Floor,
 # Boston, MA 02110-1301, USA.
 
-# Import from the future
-from __future__ import absolute_import
+from collections.abc import Callable
 
 # Import from pygit2
 from .errors import check_error
-from .ffi import ffi, C
+from .ffi import C, ffi
 from .utils import to_bytes
 
 
-class Refspec(object):
-    def __init__(self, owner, ptr):
+class Refspec:
+    """The constructor is for internal use only."""
+
+    def __init__(self, owner, ptr) -> None:
         self._owner = owner
         self._refspec = ptr
 
     @property
-    def src(self):
+    def src(self) -> str:
         """Source or lhs of the refspec"""
-        return ffi.string(C.git_refspec_src(self._refspec)).decode()
+        return ffi.string(C.git_refspec_src(self._refspec)).decode('utf-8')
 
     @property
-    def dst(self):
-        """Destinaton or rhs of the refspec"""
-        return ffi.string(C.git_refspec_dst(self._refspec)).decode()
+    def dst(self) -> str:
+        """Destination or rhs of the refspec"""
+        return ffi.string(C.git_refspec_dst(self._refspec)).decode('utf-8')
 
     @property
-    def force(self):
+    def force(self) -> bool:
         """Whether this refspeca llows non-fast-forward updates"""
         return bool(C.git_refspec_force(self._refspec))
 
     @property
-    def string(self):
+    def string(self) -> str:
         """String which was used to create this refspec"""
-        return ffi.string(C.git_refspec_string(self._refspec)).decode()
+        return ffi.string(C.git_refspec_string(self._refspec)).decode('utf-8')
 
     @property
     def direction(self):
         """Direction of this refspec (fetch or push)"""
         return C.git_refspec_direction(self._refspec)
 
-    def src_matches(self, ref):
-        """src_matches(str) -> Bool
-
-        Returns whether the given string matches the source of this refspec"""
+    def src_matches(self, ref: str) -> bool:
+        """Return True if the given string matches the source of this refspec,
+        False otherwise.
+        """
         return bool(C.git_refspec_src_matches(self._refspec, to_bytes(ref)))
 
-    def dst_matches(self, ref):
-        """dst_matches(str) -> Bool
-
-        Returns whether the given string matches the destination of this
-        refspec"""
+    def dst_matches(self, ref: str) -> bool:
+        """Return True if the given string matches the destination of this
+        refspec, False otherwise."""
         return bool(C.git_refspec_dst_matches(self._refspec, to_bytes(ref)))
 
-    def _transform(self, ref, fn):
+    def _transform(self, ref: str, fn: Callable) -> str:
         buf = ffi.new('git_buf *', (ffi.NULL, 0))
         err = fn(buf, self._refspec, to_bytes(ref))
         check_error(err)
 
         try:
-            return ffi.string(buf.ptr).decode()
+            return ffi.string(buf.ptr).decode('utf-8')
         finally:
-            C.git_buf_free(buf)
+            C.git_buf_dispose(buf)
 
-    def transform(self, ref):
-        """transform(str) -> str
-
-        Transform a reference name according to this refspec from the lhs to
-        the rhs."""
+    def transform(self, ref: str) -> str:
+        """Transform a reference name according to this refspec from the lhs to
+        the rhs. Return an string.
+        """
         return self._transform(ref, C.git_refspec_transform)
 
-    def rtransform(self, ref):
-        """transform(str) -> str
-
-        Transform a reference name according to this refspec from the lhs
-        to the rhs"""
+    def rtransform(self, ref: str) -> str:
+        """Transform a reference name according to this refspec from the lhs to
+        the rhs. Return an string.
+        """
         return self._transform(ref, C.git_refspec_rtransform)
